==> haskell-pandoc-lua-marshal-0.2.8-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-marshal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-marshal
version:              0.2.8
visibility:           public
id:                   pandoc-lua-marshal-0.2.8-JKzbYVkLAbA4SpnfCm1Xk2
key:                  pandoc-lua-marshal-0.2.8-JKzbYVkLAbA4SpnfCm1Xk2
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel, John MacFarlane
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel, John MacFarlane
homepage:             https://github.com/pandoc/pandoc-lua-marshal
synopsis:             Use pandoc types in Lua
description:
    This package provides functions to marshal and unmarshal
    pandoc document types to and from Lua.

    The values of most types are pushed to pandoc as "userdata"
    objects that wrap a stable pointer to the Haskell value;
    these objects come with methods to access and modify their
    properties.

    Sequences are pushed as normal Lua tables, but are
    augmented with convenience functions.

category:             Foreign
abi:                  17b188c65e78cfc7c50023f203b90956
exposed:              True
exposed-modules:
    Text.Pandoc.Lua.Marshal.AST Text.Pandoc.Lua.Marshal.Alignment
    Text.Pandoc.Lua.Marshal.Attr Text.Pandoc.Lua.Marshal.Block
    Text.Pandoc.Lua.Marshal.Cell Text.Pandoc.Lua.Marshal.Citation
    Text.Pandoc.Lua.Marshal.CitationMode
    Text.Pandoc.Lua.Marshal.Content Text.Pandoc.Lua.Marshal.Filter
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.Inline
    Text.Pandoc.Lua.Marshal.List Text.Pandoc.Lua.Marshal.ListAttributes
    Text.Pandoc.Lua.Marshal.MathType Text.Pandoc.Lua.Marshal.MetaValue
    Text.Pandoc.Lua.Marshal.Pandoc Text.Pandoc.Lua.Marshal.QuoteType
    Text.Pandoc.Lua.Marshal.Row Text.Pandoc.Lua.Marshal.SimpleTable
    Text.Pandoc.Lua.Marshal.TableFoot Text.Pandoc.Lua.Marshal.TableHead
    Text.Pandoc.Lua.Marshal.TableParts

hidden-modules:
    Text.Pandoc.Lua.Marshal.Shared Text.Pandoc.Lua.Topdown
    Text.Pandoc.Lua.SpliceList Text.Pandoc.Lua.Walk

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-marshal
hs-libraries:         HSpandoc-lua-marshal-0.2.8-JKzbYVkLAbA4SpnfCm1Xk2
depends:
    aeson-2.1.2.1-IZ8jLcnEISD7S5Vyf2Tehm base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 exceptions-0.10.5
    hslua-2.3.0-6eoJQAjnS135D8C7uRZXRH
    hslua-list-1.1.3-JnSrYSahUVm1tAznV8P9Uv
    hslua-marshalling-2.3.1-IobdForZPq5BlkJKSOSy5m
    pandoc-types-1.23.1-DkJitg32dGYAvPxFYUNIVd
    safe-0.3.21-KEfOvx15i1f7ewOxq0ZYoN text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-marshal/html/pandoc-lua-marshal.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-marshal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-lua-marshal-0.2.8-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-marshal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-marshal
version:              0.2.8
visibility:           public
id:                   pandoc-lua-marshal-0.2.8-DZtMRKYycbW4PFFlllRNG7
key:                  pandoc-lua-marshal-0.2.8-DZtMRKYycbW4PFFlllRNG7
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel, John MacFarlane
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel, John MacFarlane
homepage:             https://github.com/pandoc/pandoc-lua-marshal
synopsis:             Use pandoc types in Lua
description:
    This package provides functions to marshal and unmarshal
    pandoc document types to and from Lua.

    The values of most types are pushed to pandoc as "userdata"
    objects that wrap a stable pointer to the Haskell value;
    these objects come with methods to access and modify their
    properties.

    Sequences are pushed as normal Lua tables, but are
    augmented with convenience functions.

category:             Foreign
abi:                  79f3eb9873658e3a9817ed9fd310a559
exposed:              True
exposed-modules:
    Text.Pandoc.Lua.Marshal.AST Text.Pandoc.Lua.Marshal.Alignment
    Text.Pandoc.Lua.Marshal.Attr Text.Pandoc.Lua.Marshal.Block
    Text.Pandoc.Lua.Marshal.Cell Text.Pandoc.Lua.Marshal.Citation
    Text.Pandoc.Lua.Marshal.CitationMode
    Text.Pandoc.Lua.Marshal.Content Text.Pandoc.Lua.Marshal.Filter
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.Inline
    Text.Pandoc.Lua.Marshal.List Text.Pandoc.Lua.Marshal.ListAttributes
    Text.Pandoc.Lua.Marshal.MathType Text.Pandoc.Lua.Marshal.MetaValue
    Text.Pandoc.Lua.Marshal.Pandoc Text.Pandoc.Lua.Marshal.QuoteType
    Text.Pandoc.Lua.Marshal.Row Text.Pandoc.Lua.Marshal.SimpleTable
    Text.Pandoc.Lua.Marshal.TableFoot Text.Pandoc.Lua.Marshal.TableHead
    Text.Pandoc.Lua.Marshal.TableParts

hidden-modules:
    Text.Pandoc.Lua.Marshal.Shared Text.Pandoc.Lua.Topdown
    Text.Pandoc.Lua.SpliceList Text.Pandoc.Lua.Walk

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-marshal
hs-libraries:         HSpandoc-lua-marshal-0.2.8-DZtMRKYycbW4PFFlllRNG7
depends:
    aeson-2.1.2.1-IZ8jLcnEISD7S5Vyf2Tehm base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 exceptions-0.10.5
    hslua-2.3.0-6eoJQAjnS135D8C7uRZXRH
    hslua-list-1.1.4-ED9w748waifBD2R9h1Z5AI
    hslua-marshalling-2.3.1-IobdForZPq5BlkJKSOSy5m
    pandoc-types-1.23.1-DkJitg32dGYAvPxFYUNIVd
    safe-0.3.21-KEfOvx15i1f7ewOxq0ZYoN text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-marshal/html/pandoc-lua-marshal.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-marshal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
